@@ -1,5 +1,5 @@
 ;;; recent-files.el --- Maintain menu of recently opened files.
-;;; $Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.7 2002/05/11 05:41:23 youngs Exp $
+;;; $Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.8 2003/06/18 17:22:35 viteno Exp $
 ;;;
 ;;; Copyright (C) 1994, 1995 Juergen Nickelsen <nickel@cs.tu-berlin.de>
 ;;; Copyright (C) 2002 Ben Wing.
@@ -421,7 +421,7 @@ If the buffer has changed, the menu must be rebuilt.")
   "Return a string identifying the current version of recent-files.
 If called interactively, show it in the echo area."
   (interactive)
-  (let ((version "$Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.7 2002/05/11 05:41:23 youngs Exp $"))
+  (let ((version "$Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.8 2003/06/18 17:22:35 viteno Exp $"))
     (if (interactive-p)
 	(message version)
       version)))
@@ -751,4 +751,19 @@ Comparison is done with equal."
   (setq recent-files-save-list-on-exit (not recent-files-save-list-on-exit))
   (setq recent-files-list-changed-p t))
 
+;; User commands
+;;;###autoload
+(defun recent-files-visit-file (filename &optional codesys)
+  "Visit a recent file.
+Visit a file FILENAME that was visited recently.  Optional second argument
+specifies the coding system to use when decoding the file.  Interactively,
+with a prefix argument, you will be prompted for the coding system."
+  (interactive (list (progn
+                       (unless recent-files-list
+                         (recent-files-initialize))
+                       (completing-read "Recent file: " recent-files-list))
+                     (if current-prefix-arg
+                         (read-coding-system "Coding system: ")
+                       nil)))
+  (find-file filename codesys))
 ;;; EOF
